@@ -1741,6 +1741,48 @@ int deref1(int x, int th)
     return (NIL);
 }
 
+/* reverse deref for CLPFD */
+int revderef(int x, int th)
+{
+    int temp;
+
+    if (nullp(x))
+	return (NIL);
+    else if (alpha_variable_p(x))
+	return (revderef1(x, th));
+    else if (!structurep(x))
+	return (x);
+    else {
+	temp = wcons(revderef(car(x), th), revderef(cdr(x), th), th);
+	SET_AUX(temp, GET_AUX(x));
+	return (temp);
+    }
+}
+
+int revderef1(int x, int th)
+{
+
+    int y;
+
+    y = NIL;
+    if (alpha_variable_p(x)) {
+	// reverse-findvar(x);
+	y = x;
+      loop:
+	y--;
+	while (y > CELLSIZE) {
+	    if (variant[y - CELLSIZE][th] == x) {
+		x = y;
+		goto loop;
+	    }
+	    y--;
+	}
+	return (x);
+    } else
+	return (x);
+
+    return (NIL);
+}
 
 
 int unify(int x, int y, int th)
