@@ -192,7 +192,26 @@ socklen_t server_len;
 struct sockaddr_in server_addr, client_addr;
 
 /* -----CLPFD-------------------------- */
-int constraint_set = NIL;
+int fd_sets = NIL;
+int fd_domain[256];
+int fd_var_max;
+int fd_var_idx;
+int fd_min[256];
+int fd_max[256];
+int fd_len[256];
+int fd_unique[256];
+int fd_analyze_sw;
+int fd_selected[256];
+int fd_sel_idx;
+int fd_var_free;
+int fd_vars = NIL;
+int fd_removed[256][256];
+int fd_rem_idx[256];
+int fd_rem_sw;
+int fd_queue[2048];
+int fd_deque_idx;
+int fd_enque_idx;
+int fd_trace;
 
 //-----editor-----
 char buffer[BUFSIZE][10];
@@ -427,8 +446,23 @@ void init_repl(void)
 	i = cdr(i);
     }
     // CLPFD
-    constraint_set = NIL;
-
+    fd_sets = NIL;
+    fd_var_max = 0;
+    fd_var_idx = 0;
+    fd_sel_idx = 0;
+    fd_var_free = 0;
+    fd_deque_idx = 0;
+    fd_enque_idx = 0;
+    for (i = 0; i < 256; i++) {
+	fd_domain[i] = -1;
+	fd_unique[i] = 0;
+	fd_rem_idx[i] = 0;
+    }
+    while (!nullp(fd_vars)) {
+	SET_ARITY(car(fd_vars), 0);
+	SET_VAR(car(fd_vars), 0);
+	fd_vars = cdr(fd_vars);
+    }
 }
 
 void query(int x, int th)
