@@ -17,7 +17,7 @@ address
  5,000,001 - 30,000,000  working area 
 30,000,001 - 32,000,000  variant area
 */
-#define VERSION     4.08
+#define VERSION     4.37
 #define CELLSIZE    30000000  // if raspberry PI set smaller size.
 #define HEAPSIZE     5000000
 #define FREESIZE         500
@@ -67,6 +67,8 @@ address
 #define TIMEROFF    50
 #define SLASH       52
 #define ERROBJ      54
+#define UNKNOWN     60
+#define COMPLETE    62
 #define HASHTBSIZE 107
 #define BIGNUM_BASE 1000000000
 #define SMALL_INT_MAX       1000000000
@@ -357,8 +359,26 @@ extern socklen_t server_len;
 extern struct sockaddr_in server_addr, client_addr;
 
 /* -----CLPFD-------------------------- */
-extern int constraint_set;
-
+extern int fd_sets;
+extern int fd_domain[256];
+extern int fd_var_max;
+extern int fd_var_idx;
+extern int fd_min[256];
+extern int fd_max[256];
+extern int fd_len[256];
+extern int fd_unique[256];
+extern int fd_analyze_sw;
+extern int fd_selected[256];
+extern int fd_sel_idx;
+extern int fd_var_free;
+extern int fd_vars;
+extern int fd_removed[256][256];
+extern int fd_rem_idx[256];
+extern int fd_rem_sw;
+extern int fd_queue[2048];
+extern int fd_deque_idx;
+extern int fd_enque_idx;
+extern int fd_trace;
 
 #ifdef __APPLE__
 #define FLUSH               fpurge(stdin);
@@ -1078,6 +1098,8 @@ int deref(int x, int th);
 int deref1(int x, int th);
 int disjunctionp(int addr);
 int divide(int arg1, int arg2, int th);
+int each_car(int x);
+int each_cdr(int x);
 int eqgreaterp(int x1, int x2);
 int eqlp(int addr1, int addr2);
 int eqp(int addr1, int addr2);
@@ -1283,6 +1305,8 @@ int predicatep(int addr);
 int pred_to_str(int x);
 int prefixp(int addr);
 int prev(int x);
+int propagate_all(int sets);
+int propagate(int sets);
 int prove(int goal, int bindings, int rest, int th);
 int prove_all(int goals, int bindings, int th);
 int quoted_option_p(int x);
@@ -1306,7 +1330,10 @@ int replace(int x, int lis);
 int reposition_option_p(int x);
 int resolve_all(int end, int bindings, int n);
 int resolve(int end, int bindings, int trail, int n);
+int revderef(int x, int th);
+int revderef1(int x, int th);
 int reverse(int x);
+int rev_variable_convert(int x);
 int set_ac(int x, int th);
 int set_sp(int x, int th);
 int set_wp(int x, int th);
@@ -1518,6 +1545,10 @@ int b_timer_microseconds(int arglist, int rest, int th);
 //----CLPFD---------------
 int b_add_constraint(int arglist, int rest, int th);
 int b_constraint_set(int arglist, int rest, int th);
+int b_constraint_var(int arglist, int rest, int th);
+int b_constraint_vars(int arglist, int rest, int th);
+int b_label(int arglist, int rest, int th);
+int b_all_different(int arglist, int rest, int th);
 
 // edit 
 struct position{
